package com.fs.hisStore.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.fs.hisStore.mapper.FsStoreProductTemplateScrmMapper;
import com.fs.hisStore.domain.FsStoreProductTemplateScrm;
import com.fs.hisStore.service.IFsStoreProductTemplateScrmService;

/**
 * 商品模板Service业务层处理
 * 
 * @author fs
 * @date 2022-03-15
 */
@Service
public class FsStoreProductTemplateScrmServiceImpl implements IFsStoreProductTemplateScrmService
{
    @Autowired
    private FsStoreProductTemplateScrmMapper fsStoreProductTemplateMapper;

    /**
     * 查询商品模板
     * 
     * @param tempId 商品模板ID
     * @return 商品模板
     */
    @Override
    public FsStoreProductTemplateScrm selectFsStoreProductTemplateById(Long tempId)
    {
        return fsStoreProductTemplateMapper.selectFsStoreProductTemplateById(tempId);
    }

    /**
     * 查询商品模板列表
     * 
     * @param fsStoreProductTemplate 商品模板
     * @return 商品模板
     */
    @Override
    public List<FsStoreProductTemplateScrm> selectFsStoreProductTemplateList(FsStoreProductTemplateScrm fsStoreProductTemplate)
    {
        return fsStoreProductTemplateMapper.selectFsStoreProductTemplateList(fsStoreProductTemplate);
    }

    /**
     * 新增商品模板
     * 
     * @param fsStoreProductTemplate 商品模板
     * @return 结果
     */
    @Override
    public int insertFsStoreProductTemplate(FsStoreProductTemplateScrm fsStoreProductTemplate)
    {
        return fsStoreProductTemplateMapper.insertFsStoreProductTemplate(fsStoreProductTemplate);
    }

    /**
     * 修改商品模板
     * 
     * @param fsStoreProductTemplate 商品模板
     * @return 结果
     */
    @Override
    public int updateFsStoreProductTemplate(FsStoreProductTemplateScrm fsStoreProductTemplate)
    {
        return fsStoreProductTemplateMapper.updateFsStoreProductTemplate(fsStoreProductTemplate);
    }

    /**
     * 批量删除商品模板
     * 
     * @param tempIds 需要删除的商品模板ID
     * @return 结果
     */
    @Override
    public int deleteFsStoreProductTemplateByIds(Long[] tempIds)
    {
        return fsStoreProductTemplateMapper.deleteFsStoreProductTemplateByIds(tempIds);
    }

    /**
     * 删除商品模板信息
     * 
     * @param tempId 商品模板ID
     * @return 结果
     */
    @Override
    public int deleteFsStoreProductTemplateById(Long tempId)
    {
        return fsStoreProductTemplateMapper.deleteFsStoreProductTemplateById(tempId);
    }
}
